Fedora Messaging
================

.. image:: https://img.shields.io/pypi/v/fedora-messaging.svg
    :target: https://pypi.org/project/fedora-messaging/

.. image:: https://img.shields.io/pypi/pyversions/fedora-messaging.svg
    :target: https://pypi.org/project/fedora-messaging/

.. image:: https://readthedocs.org/projects/docs/badge/?version=latest
    :alt: Documentation Status
    :target: https://fedora-messaging.readthedocs.io/en/latest/?badge=latest

Tools and APIs to make working with AMQP in Fedora easier.
